"use client";
import ResultSearchBar from "@comp/Navbar/ResultSearchBar/page";
import AppContext from "@ctx/AppContext";
import { useContext, useEffect, useRef, useState } from "react";

const SearchSideBar = () => {
  const CTX = useContext(AppContext);
  const [searchValue, setSearchValue] = useState("");
  const isSearched = CTX.state.isSearched;

  const inputRef = useRef(null);

  const handleRemoveSearch = () => {
    CTX.setSearchResultData([]);
    setSearchValue("");
    CTX.setIsSearched(false);
  };

  useEffect(() => {
    if (CTX.state.closeNavbar) {
      inputRef.current.focus();
    }
    setSearchValue("");
  }, [CTX.state.closeNavbar]);

  const handleInputChange = (event) => {
    setSearchValue(event.target.value);
  };

  useEffect(() => {
    // Define a function to send the request
    const sendRequest = async () => {
      CTX.fetchSearchResult(searchValue);
    };

    // Set a timer to send the request after 2000 milliseconds of inactivity
    const timer = setTimeout(() => {
      if (searchValue.trim() !== "") {
        sendRequest();
        CTX.setIsSearched(true);
      }

      if (searchValue == "") {
        CTX.setIsSearched(false);
      }
    }, 1000);

    // Clean up function to clear the timer on component unmount or when searchTerm changes
    return () => clearTimeout(timer);
  }, [searchValue]);

  return (
    <>
      <div className="mt-5 px-3">
        <div className="absolute right-0  mr-[15px] mt-[0px]">
          <div
            className="bg-gray-100 rounded-r-lg h-[47px] w-[40px] border-l-[1px] mt-[2px] "
            onClick={() => {
              CTX.setCloseNavbar(true);
            }}
          >
            <div className="pt-[9px] ">
              <svg
                width="25"
                height="28"
                viewBox="0 0 235 124"
                fill="none"
                xmlns="http://www.w3.org/2000/svg"
                className="mx-auto"
              >
                <path
                  d="M145.5 124L145.5 93.4995L235 93.4995L235 124L145.5 124ZM75.5 26.4998L75.5 0.499997L235 0.499997L235 26.4998L75.5 26.4998ZM0.499998 72.4996L0.499997 47.4996L235 47.4996L235 72.4996L0.499998 72.4996Z"
                  fill="black"
                  fill-opacity="0.73"
                />
              </svg>
            </div>
          </div>
        </div>
        <input
          type="text"
          ref={inputRef}
          className="form-control  bg-gray-100 !border-[0px] border-gray-100 rounded-lg text-right focus:!border-[0px] !text-sm !pr-[60px]  "
          placeholder="دستت برای جست و جو بازه"
          onFocus={() => CTX.setCloseNavbar(true)}
          value={searchValue}
          onChange={(e) => handleInputChange(e)}
        />

        {!isSearched ? (
          <div className="absolute mt-[-46px] ml-[6px]">
            <div className="w-[40px] h-[40px] bg-gray-200  rounded-lg pt-2">
              <svg
                width="17"
                height="17"
                viewBox="0 0 275 275"
                fill="none"
                xmlns="http://www.w3.org/2000/svg"
                className="mx-auto mt-1"
              >
                <path
                  d="M215.913 215.913L265 265M250.832 130.822C250.832 197.553 196.915 251.644 130.424 251.644C63.9166 251.644 10 197.552 10 130.838C10 64.0759 63.9166 10 130.408 10C196.915 10 250.832 64.0919 250.832 130.822Z"
                  stroke="black"
                  stroke-width="18.75"
                  stroke-linecap="round"
                  stroke-linejoin="round"
                />
              </svg>
            </div>
          </div>
        ) : (
          <div
            className="absolute mt-[-46px] ml-[6px]"
            onClick={() => handleRemoveSearch()}
          >
            <div className="w-[40px] h-[40px] bg-gray-200  rounded-lg pt-2">
              <svg
                width="10"
                height="10"
                viewBox="0 0 214 214"
                fill="none"
                xmlns="http://www.w3.org/2000/svg"
                className="mx-auto mt-[7px] "
              >
                <path
                  d="M4.42496 8.34954L6.24996 6.24955C9.42467 3.07411 13.6335 1.1434 18.1112 0.80849C22.589 0.473578 27.0382 1.7567 30.65 4.42455L32.75 6.24955L107 80.4745L181.25 6.22455C182.98 4.43456 185.05 3.00714 187.338 2.02557C189.626 1.04399 192.087 0.527921 194.576 0.507469C197.066 0.487016 199.535 0.962591 201.839 1.90644C204.142 2.8503 206.235 4.24353 207.995 6.00484C209.755 7.76615 211.146 9.86026 212.087 12.165C213.029 14.4697 213.502 16.9389 213.48 19.4285C213.457 21.9181 212.938 24.3783 211.955 26.6654C210.971 28.9525 209.542 31.0208 207.75 32.7495L133.525 107L207.775 181.25C210.947 184.427 212.873 188.638 213.203 193.116C213.533 197.593 212.246 202.041 209.575 205.65L207.75 207.75C204.575 210.925 200.366 212.856 195.889 213.191C191.411 213.526 186.962 212.242 183.35 209.575L181.25 207.75L107 133.525L32.75 207.775C31.0195 209.565 28.9498 210.992 26.6618 211.974C24.3738 212.955 21.9132 213.471 19.4236 213.492C16.9339 213.512 14.4652 213.036 12.1613 212.093C9.85749 211.149 7.76468 209.756 6.00503 207.994C4.24538 206.233 2.85412 204.139 1.91244 201.834C0.970764 199.529 0.497518 197.06 0.520318 194.571C0.543117 192.081 1.06151 189.621 2.04524 187.334C3.02897 185.047 4.45835 182.978 6.24996 181.25L80.475 107L6.22496 32.7495C3.05326 29.5717 1.12717 25.3612 0.796856 20.8836C0.466538 16.4059 1.75392 11.9584 4.42496 8.34954Z"
                  fill="black"
                />
              </svg>
            </div>
          </div>
        )}
      </div>

      {/* {true && (
        <div
          className={`relative !z-[100] tr03 ${
            true ? "opacity-100" : "opacity-100"
          } `}
          // onClick={() => setSearchResultShow(!searchResultShow)}
        >
          <ResultSearchBar
            searchResultProductData={searchResultProductData}
            searchResultCategoryData={searchResultCategoryData}
          />
        </div>
      )} */}
    </>
  );
};

export default SearchSideBar;
